@@ -1,13 +1,13 @@
 """Implements the main class of this package: :py:class:`BoostrapHistogram`."""
 
 from copy import copy, deepcopy
-from typing import Any, Optional, Tuple, Union
+from typing import Any, Optional, Tuple, Union, cast
 
 import boost_histogram as bh
-import numpy as np
+import numpy as np  # type: ignore
 
 try:
-    from numpy.typing import ArrayLike
+    from numpy.typing import ArrayLike  # type: ignore
 except (ImportError, ModuleNotFoundError):
     ArrayLike = np.ndarray
 
@@ -42,20 +42,46 @@ class BootstrapHistogram:
     def __init__(
         self,
         *axes: bh.axis.Axis,
-        numsamples: int = 1000,
+        numsamples: int = 100,
         rng: Union[int, np.random.Generator, None] = None,
         **kwargs: Any,
     ):
+        # we defer the initialization of these variables until _intialize.
+        self._nominal: bh.Histogram = None  # type: ignore
+        self._hist: bh.Histogram = None  # type: ignore
+        self._random: np.random.Generator = None
         axeslist = list(axes)
-        self._nominal = bh.Histogram(*axeslist, **kwargs)
-        axeslist.append(bh.axis.Integer(0, numsamples))
+        nominal = bh.Histogram(*axeslist, **kwargs)
+        axeslist.append(bh.axis.Integer(0, numsamples, underflow=False, overflow=False))
+        samples = bh.Histogram(*axeslist, **kwargs)
+        self._initialize(nominal, samples, rng)
+
+    def _initialize(
+        self,
+        nominal: bh.Histogram,
+        samples: bh.Histogram,
+        rng: Union[int, np.random.Generator, None] = None,
+    ) -> None:
+        self._nominal = nominal
+        self._hist = samples
         self._random = np.random.default_rng(rng)
-        self._hist = bh.Histogram(*axeslist, **kwargs)
         # when filling with very large arrays, the fast filling method may use too
         # much memory, fall back to the slower method when the array size gets above
         # this threshold
         self._threshold_for_fast_method = 1000000
 
+    @classmethod
+    def _from_bh_histogram(
+        cls,
+        nominal: bh.Histogram,
+        samples: bh.Histogram,
+        rng: Union[int, np.random.Generator, None],
+    ) -> "BootstrapHistogram":
+        result = cls.__new__(cls)
+        result._nominal = nominal
+        result._initialize(nominal, samples, rng)
+        return result
+
     @property
     def nominal(self) -> bh.Histogram:
         """A histogram of the filled values, with no
@@ -71,7 +97,7 @@ class BootstrapHistogram:
         """
         return self._hist
 
-    def mean(self, flow=False) -> np.ndarray:
+    def mean(self, flow: bool = False) -> np.ndarray:
         """
         Binned sample mean.
 
@@ -83,7 +109,7 @@ class BootstrapHistogram:
         """
         return np.mean(self.view(flow=flow), axis=-1)
 
-    def std(self, flow=False) -> np.ndarray:
+    def std(self, flow: bool = False) -> np.ndarray:
         """
         Binned sample standard deviation.
 
@@ -96,7 +122,7 @@ class BootstrapHistogram:
         return np.std(self.view(flow=flow), axis=-1)
 
     def percentile(
-        self, q: float, flow=False, interpolation: str = "linear"
+        self, q: float, flow: bool = False, interpolation: str = "linear"
     ) -> np.ndarray:
         """
         Binned q-th percentile.
@@ -250,7 +276,7 @@ class BootstrapHistogram:
             hist.fill(*args, index, weight=sampleweights, **kwargs)
         return self
 
-    def view(self, flow=False) -> Any:
+    def view(self, flow: bool = False) -> Any:
         """
         Return a view of the underlying histogram bootstrap sample values.
         """
@@ -309,7 +335,9 @@ class BootstrapHistogram:
             result._nominal -= other
         return result
 
-    def __mul__(self, other: Union["BootstrapHistogram", ArrayLike, float]):
+    def __mul__(
+        self, other: Union["BootstrapHistogram", ArrayLike, float]
+    ) -> "BootstrapHistogram":
         result = deepcopy(self)
         if isinstance(other, BootstrapHistogram):
             result._hist *= other._hist
@@ -324,7 +352,9 @@ class BootstrapHistogram:
     ) -> "BootstrapHistogram":
         return self * other
 
-    def __truediv__(self, other: Union["BootstrapHistogram", ArrayLike, float]):
+    def __truediv__(
+        self, other: Union["BootstrapHistogram", ArrayLike, float]
+    ) -> "BootstrapHistogram":
         result = deepcopy(self)
         if isinstance(other, BootstrapHistogram):
             result._hist /= other._hist
@@ -353,9 +383,12 @@ class BootstrapHistogram:
         #  pylint: disable=protected-access
         result = copy(self)
         arglist = list(args)
-        result._nominal = self._nominal.project(*arglist)
         sampleaxis = len(self.axes) - 1
+        result._nominal = cast(
+            bh.Histogram,
+            self._nominal.project(*[arg for arg in arglist if arg != sampleaxis]),
+        )
         if sampleaxis not in arglist:
             arglist.append(sampleaxis)
-        result._hist = self._hist.project(*arglist)
+        result._hist = cast(bh.Histogram, self._hist.project(*arglist))
         return result
